@@ -2,7 +2,8 @@
 # -*- coding: utf-8 -*-
 # patterns.py: Common wildcard searching/filtering functionality for files.
 #
-# Copyright (C) 2010 Gora Khargosh <gora.khargosh@gmail.com>
+# Copyright (C) 2010 Yesudeep Mangalapilly <yesudeep@gmail.com>
+# Copyright (C) 2018 Nuxeo
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -25,7 +26,7 @@
 """
 :module: pathtools.patterns
 :synopsis: Wildcard pattern matching and filtering functions for paths.
-:author: Gora Khargosh <gora.khargosh@gmail.com>
+:author: Yesudeep Mangalapilly <yesudeep@gmail.com>
 
 Functions
 ---------
@@ -36,10 +37,7 @@ Functions
 
 from fnmatch import fnmatch, fnmatchcase
 
-__all__ = ['match_path',
-           'match_path_against',
-           'match_any_paths',
-           'filter_paths']
+__all__ = ["match_path", "match_path_against", "match_any_paths", "filter_paths"]
 
 
 def _string_lower(s):
@@ -56,7 +54,7 @@ def _string_lower(s):
 
 
 def match_path_against(pathname, patterns, case_sensitive=True):
-    """
+    r"""
     Determines whether the pathname matches any of the given wildcard patterns,
     optionally ignoring the case of the pathname and patterns.
 
@@ -83,7 +81,9 @@ def match_path_against(pathname, patterns, case_sensitive=True):
     """
     if case_sensitive:
         match_func = fnmatchcase
-        pattern_transform_func = (lambda w: w)
+
+        def pattern_transform_func(string):
+            return string
     else:
         match_func = fnmatch
         pathname = pathname.lower()
@@ -95,10 +95,7 @@ def match_path_against(pathname, patterns, case_sensitive=True):
     return False
 
 
-def _match_path(pathname,
-                included_patterns,
-                excluded_patterns,
-                case_sensitive=True):
+def _match_path(pathname, included_patterns, excluded_patterns, case_sensitive=True):
     """Internal function same as :func:`match_path` but does not check arguments.
 
     Doctests::
@@ -111,7 +108,7 @@ def _match_path(pathname,
         >>> _match_path("/users/gorakhargosh/FOOBAR.PY", ["*.py"], ["*.PY"], False)
         Traceback (most recent call last):
             ...
-        ValueError: conflicting patterns `set(['*.py'])` included and excluded
+        ValueError: conflicting patterns `['*.py']` included and excluded
     """
     if not case_sensitive:
         included_patterns = set(map(_string_lower, included_patterns))
@@ -121,17 +118,17 @@ def _match_path(pathname,
         excluded_patterns = set(excluded_patterns)
     common_patterns = included_patterns & excluded_patterns
     if common_patterns:
-        raise ValueError('conflicting patterns `%s` included and excluded'\
-                         % common_patterns)
-    return (match_path_against(pathname, included_patterns, case_sensitive)\
-            and not match_path_against(pathname, excluded_patterns,
-                                       case_sensitive))
+        raise ValueError(
+            "conflicting patterns `%s` included and excluded" % list(common_patterns)
+        )
+    return match_path_against(
+        pathname, included_patterns, case_sensitive
+    ) and not match_path_against(pathname, excluded_patterns, case_sensitive)
 
 
-def match_path(pathname,
-               included_patterns=None,
-               excluded_patterns=None,
-               case_sensitive=True):
+def match_path(
+    pathname, included_patterns=None, excluded_patterns=None, case_sensitive=True
+):
     """
     Matches a pathname against a set of acceptable and ignored patterns.
 
@@ -167,17 +164,16 @@ def match_path(pathname,
         >>> match_path("/users/gorakhargosh/FOOBAR.PY", ["*.py"], ["*.PY"], False)
         Traceback (most recent call last):
             ...
-        ValueError: conflicting patterns `set(['*.py'])` included and excluded
+        ValueError: conflicting patterns `['*.py']` included and excluded
     """
     included = ["*"] if included_patterns is None else included_patterns
     excluded = [] if excluded_patterns is None else excluded_patterns
     return _match_path(pathname, included, excluded, case_sensitive)
 
 
-def filter_paths(pathnames,
-                 included_patterns=None,
-                 excluded_patterns=None,
-                 case_sensitive=True):
+def filter_paths(
+    pathnames, included_patterns=None, excluded_patterns=None, case_sensitive=True
+):
     """
     Filters from a set of paths based on acceptable patterns and
     ignorable patterns.
@@ -206,7 +202,7 @@ def filter_paths(pathnames,
         True
         >>> set(filter_paths(pathnames, ["*.py", "*.conf"], ["*.status"], case_sensitive=True)) == set(["/users/gorakhargosh/foobar.py", "/etc/pdnsd.conf"])
         True
-    """
+    """  # noqa
     included = ["*"] if included_patterns is None else included_patterns
     excluded = [] if excluded_patterns is None else excluded_patterns
 
@@ -217,10 +213,10 @@ def filter_paths(pathnames,
         if _match_path(pathname, included, excluded, case_sensitive):
             yield pathname
 
-def match_any_paths(pathnames,
-                    included_patterns=None,
-                    excluded_patterns=None,
-                    case_sensitive=True):
+
+def match_any_paths(
+    pathnames, included_patterns=None, excluded_patterns=None, case_sensitive=True
+):
     """
     Matches from a set of paths based on acceptable patterns and
     ignorable patterns.
@@ -252,7 +248,7 @@ def match_any_paths(pathnames,
         False
         >>> match_any_paths(pathnames, ["*.txt"], case_sensitive=True)
         False
-    """
+    """  # noqa
     included = ["*"] if included_patterns is None else included_patterns
     excluded = [] if excluded_patterns is None else excluded_patterns
 
